@@ -8,7 +8,7 @@ if [ _${SCRIPT}_ != _spruch_  -a _${SCRIPT}_ != _fortune_  ] ; then
 fi
 
 lang=$(locale | sed -ne 's/"$//;s/^LC_MESSAGES="\?//p')
-l=$(sed -ne "s/^$(echo $lang | sed 's/\([].^$*[]\)/\\\1/g')[ 	]\+//ip" /etc/locale.alias)
+l=$(sed -ne "s/^$(echo $lang | sed 's/\(\.\|\^\|\$\|\*\|\[\)/\\\1/g')[ 	]\+//ip" /etc/locale.alias)
 [ -n "$l" ] && lang="$l"
 
 # check for the currently used charmap
